<?php
class GroupController extends ActionController {
    public function __construct($viewPath) {
		parent::__construct($viewPath);
	}
    
    public function getlist() {
        if (! $this->current_user->isAdministrator()) {
            $this->redirect('/error/denied/');
        }
        
        $groups = Group::GetAll();
        $this->view->load('group_list', array('groups'=> $groups));
        $this->view->render();
    }
    
	public function show($name) {
		if (! $this->current_user->isAdministrator()) {
            $this->redirect('/error/denied/');
        }
        
        $group = Group::GetByName($name);
        $this->view->load('group_show', array('group'=> $group));
        $this->view->render();
	}
	
    public function create() {
        $req_fields = array('group_name');
		if ( ! $this->current_user->isAdministrator() ) {
			$this->redirect('/error/denied/');
		} elseif (!$this->arrayContains($req_fields, $_POST)) {
			$this->view->load("group_create");
            $this->view->render();
		} else {
			$grp = new Group();
			$grp->name = $_POST['group_name'];
			$grp->description = isset($_POST['description']) ? $_POST['description'] : '';
			$grp->insert();
            $this->redirect('/group/getlist/');
		}
    }
    
    public function addUser($name) {
        if (! $this->current_user->isAdministrator()) {
            $this->redirect('/error/denied/');
        }
        
        $g = Group::GetByName($name);
        if (! $g) {
            $this->redirect('/error/invalid/');
        }
        
        $req_fields = array('username');
        
        if (! $this->arrayContains($req_fields, $_POST)) {
			$this->view->setMessage("Missing username");
		} else {
            $u = User::GetByName($_POST['username']);
            if ($u) {
                $ret = $g->Add($u);
				$msg = $ret ? "Added user ".$u->username." to ".$g->name : "Failed to add user";
				$this->view->setMessage($msg, $ret ? "success" : "error");
            } else {
				$this->view->setMessage("User '".$_POST['username']."' does not exist", "error");
			}
        }
		$this->redirect('/group/show/'.$g->name);
		$this->view->render();
    }
    
    public function removeUser($name) {
        
        if (! $this->current_user->isAdministrator()) {
            $this->redirect('/error/denied/');
        }
        
        $g = Group::GetByName($name);
        if (! $g) {
            $this->redirect('/error/invalid/');
        }
        
        $req_fields = array('username');
        
        if ($this->arrayContains($req_fields, $_POST)) {
            $u = User::GetByName($_POST['username']);
            if ($u) {
                $g->Remove($u);
                $this->redirect('/group/list/');
            } else {
                $this->redirect('/error/invalid/');
            }
        } else {
            $this->view->load("group_remove_user");
            $this->view->render();
        }
    }
}