<?php
class ACL {

	const READ = 'read';
	const WRITE = 'edit';
	const DELETE = 'delete';
	const CREATE = 'create';
	
	private $db = null;
	
	public function __construct() {
		$this->db = new DB();
	}
	
	public function HasPermission($user, $document, $perm) {
		if (! $user || ! $document) return false;
		$user_has_perm = $this->db->SelectUserPermission($user->username, $document->id, $perm);
		if ($user_has_perm !== null) {
			return $user_has_perm == 1;
		} else {
			$group_has_perm = $this->db->SelectGroupPermission($user->username, $document->id, $perm);
			return $group_has_perm == 1;
		}
	}
	
	public function SetPermission($user, $document, $perm, $granted) {
		$data = array('document_id'=> $document->id,
					  'permission'=> $perm,
					  'granted'=> $granted);
		if (is_a($user, 'User')) {
			$data['username'] = $user->username;
			$has_perm = $this->db->SelectUserPermission($user->username, $document->id, $perm);
			if ($has_perm !== null) {
				$this->db->UpdateUserPermission($user->username, $document->id, $perm, $granted);
			} else {
				$this->db->InsertUserPermission($data);
			}
		} else {
			$data['group_name'] = $user->name;
			$has_perm = $this->db->SelectGroupPermission($user->name, $document->id, $perm);
			if ($has_perm !== null) {
				$this->db->UpdateGroupPermission($user->name, $document->id, $perm, $granted);
			} else {
				$this->db->InsertGroupPermission($data);
			}
		}
	}
	
	public function SetDefaultPermissions($doc) {
		$admins = Group::GetByName('Administrators');
		$this->SetPermission($doc->owner, $doc, ACL::READ, true);
		$this->SetPermission($doc->owner, $doc, ACL::WRITE, true);
		$this->SetPermission($doc->owner, $doc, ACL::DELETE, true);
		$this->SetPermission($admins, $doc, ACL::READ, true);
		$this->SetPermission($admins, $doc, ACL::WRITE, true);
		$this->SetPermission($admins, $doc, ACL::DELETE, true);
	}
	
	public static function toPerm($val) {
		if (in_array($val, self::getPermissionList())) {
			return $val;
		} else  {
			return null;
		}
	}
	
	public static function getPermissionList() {
		return array(ACL::CREATE, ACL::DELETE, ACL::READ, ACL::WRITE);
	}
	
}